@@ -19,7 +19,7 @@ from . import misc
 with warnings.catch_warnings():
     warnings.filterwarnings('ignore', module='eel', category=ResourceWarning)
 
-    import eel
+    import EelForkExcludeFiles as eel
 
 
 expose_error_callback = None
@@ -88,8 +88,9 @@ def run_gui(devel=None, is_multiprocessing=False, log_file_path=None, builded_gu
             app = 'chrome'
             page = 'index.html'
             port = 0
+            init_files = ['.js', '.html']
 
-        eel.init(directory.as_posix(), ['.vue', '.js', '.html'], exlcude_patterns=['chunk-vendors'])
+        eel.init(directory.as_posix(), init_files, exlcude_patterns=['chunk-vendors'])
 
         # try:
         # if devel:
@@ -103,7 +104,6 @@ def run_gui(devel=None, is_multiprocessing=False, log_file_path=None, builded_gu
 
         # if not already_run:
 
-        eel.init(directory.as_posix(), init_files)
 
         if is_multiprocessing:
             from multiprocessing import freeze_support
@@ -138,15 +138,19 @@ def help_starter_pack_vue_app():
     ###########
 
     from mypythontools import pyvueel
+    from mypythontools.pyvueeel import expose
 
     # Expose python functions to Js with decorator
-    @eel.expose
+    @expose
         def load_data(settings):
             # You can return dict - will be object in js
             # You can return list - will be an array in js
 
             return {'Hello': 1}
 
+    # Call function from JS
+    pyvueel.eel.myfunction()
+
     # End of file
     if __name__ == '__main__':
         pyvueel.run_gui()
@@ -162,10 +166,11 @@ def help_starter_pack_vue_app():
     vue create gui
     ```
 
-    Goto folder and
+    Goto folder and optionally
 
     ```console
     vue add vuex
+    vue add vuetify
     vue add router
     ```
 
@@ -175,16 +180,24 @@ def help_starter_pack_vue_app():
 
     ```js
     if (process.env.NODE_ENV == 'development') {
+
+    try {
+        window.eel.set_host("ws://localhost:8686");
+
+    } catch (error) {
+        document.getElementById('app').innerHTML = 'Py side is not running. Start app.py with debugger.'
+        console.error(error);
+    }
+
     Vue.config.productionTip = true
     Vue.config.devtools = true
-    window.eel.set_host("ws://localhost:8686");
     } else {
     Vue.config.productionTip = false
     Vue.config.devtools = false
     }
 
     // You can expose function to be callable from python. Import and then
-    // window.eel.expose(mutate, 'mutate')
+    // window.eel.expose(function_name, 'function_name')
 
     ##########
     ### .env
